@@ -20,10 +20,12 @@ struct buffer {
 
 void buffer_init(struct buffer * buffer, size_t initial_capacity);
 void buffer_release(struct buffer * buffer);
-void buffer_push(struct buffer * buffer, const char * text);
+void buffer_push_str(struct buffer * buffer, const char * text);
 void buffer_push_char(struct buffer * buffer, int c);
-int buffer_pop(struct buffer * buffer);
+int buffer_pop_char(struct buffer * buffer);
 void buffer_flush(struct buffer * buffer, FILE * output);
+void buffer_copy(struct buffer * dest, struct buffer * src);
+void buffer_clear(struct buffer * buf);
 size_t buffer_size(struct buffer * buffer);
 
 #endif
